@@ -363,8 +363,13 @@ int lvm_snapshot_COW(kdev_t org_phys_dev,
 	unsigned long org_start, snap_start, snap_phys_dev, virt_start, pe_off;
 	unsigned long phys_start;
 	int idx = lv_snap->lv_remap_ptr, chunk_size = lv_snap->lv_chunk_size;
-	struct kiobuf * iobuf;
-	unsigned long blocks[KIO_MAX_SECTORS];
+	struct kiobuf * iobuf = lv_snap->lv_iobuf;
+#if LINUX_VERSION_CODE < KERNEL_VERSION ( 2, 4, 4)
+	static unsigned long blocklist[KIO_MAX_SECTORS];
+	unsigned long *blocks = blocklist;
+#else
+	unsigned long *blocks = iobuf->blocks;
+#endif
 	int blksize_snap, blksize_org, min_blksize, max_blksize;
 	int max_sectors, nr_sectors;
 
@@ -394,8 +399,6 @@ int lvm_snapshot_COW(kdev_t org_phys_dev,
 	       org_virt_sector);
 #endif
 
-	iobuf = lv_snap->lv_iobuf;
-
 	blksize_org = lvm_sectsize(org_phys_dev);
 	blksize_snap = lvm_sectsize(snap_phys_dev);
 	max_blksize = max(blksize_org, blksize_snap);
