@@ -3017,10 +3017,8 @@ static int _open_pv(pv_t *pv) {
 		return -ENOMEM;
 
 	err = blkdev_get(bd, FMODE_READ|FMODE_WRITE, 0, BDEV_FILE);
-	if (err) {
-		bdput(bd);
+	if (err)
 		return err;
-	}
 
 	pv->bd = bd;
 #endif
@@ -3029,12 +3027,12 @@ static int _open_pv(pv_t *pv) {
 
 static void _close_pv(pv_t *pv) {
 #if LINUX_VERSION_CODE > KERNEL_VERSION(2, 4, 0)
-	if(!pv || !pv->bd)
-		return;
-
-	blkdev_put(pv->bd, BDEV_FILE);
-	bdput(pv->bd);
-	pv->bd = 0;
+	if (pv) {
+		struct block_device *bdev = pv->bd;
+		pv->bd = NULL;
+		if (bdev)
+			blkdev_put(bdev, BDEV_FILE);
+	}
 #endif
 }
 
