@@ -9,6 +9,7 @@
  * February,March 2000
  * March,June 2001
  * October 2001
+ * January 2002
  *
  *
  * This LVM library is free software; you can redistribute it and/or
@@ -39,7 +40,9 @@
  *   26/06/2001 - fixed pv_get_size() typecast on Alpha
  *   16/01/2001 - added new lvmtab functions
  *                lvm_tab_check_free_vg_number and lvm_tab_get_all_vg_numbers
- *   23/10/2001 -added new lvmtab function lvm_tab_check_free_lv_numbers
+ *   23/10/2001 - added new lvmtab function lvm_tab_check_free_lv_numbers
+ *   16/01/2002 - ATARAID support
+ *
  */
 
 /* lvm_lib_version "LVM 0.9 by Heinz Mauelshagen   11/11/2000\n" */
@@ -162,17 +165,18 @@ extern int opt_d;
 
 /* for device classification */
 typedef enum {
-  LVM_DEVICE_TYPE_IDE = 0,
-  LVM_DEVICE_TYPE_SD,
-  LVM_DEVICE_TYPE_MD,
-  LVM_DEVICE_TYPE_LOOP,
-  LVM_DEVICE_TYPE_DASD,
-  LVM_DEVICE_TYPE_DAC960,
-  LVM_DEVICE_TYPE_NBD,
-  LVM_DEVICE_TYPE_COMPAQ_SMART2,
-  LVM_DEVICE_TYPE_COMPAQ_CISS,
-  LVM_DEVICE_TYPE_UBD,
-  LVM_DEVICE_TYPE_INVALID = -1
+  LVM_DEVICE_TYPE_INVALID = -1,	/* Unsupported device			*/
+  LVM_DEVICE_TYPE_IDE = 0,	/* IDE disk				*/
+  LVM_DEVICE_TYPE_SD,		/* SCSI disk				*/
+  LVM_DEVICE_TYPE_MD,		/* Multiple Disk driver (SoftRAID)	*/
+  LVM_DEVICE_TYPE_LOOP,		/* Loop device				*/
+  LVM_DEVICE_TYPE_DASD,		/* DASD disk (IBM S/390, zSeries)	*/
+  LVM_DEVICE_TYPE_DAC960,	/* DAC960				*/
+  LVM_DEVICE_TYPE_NBD,		/* Network Block Device			*/
+  LVM_DEVICE_TYPE_COMPAQ_SMART2,/* Compaq SMART2			*/
+  LVM_DEVICE_TYPE_COMPAQ_CISS,	/* Compaq CCISS array			*/
+  LVM_DEVICE_TYPE_UBD,		/* User-mode virtual block device	*/
+  LVM_DEVICE_TYPE_ATARAID,	/* ATA Raid				*/
 } lvm_device_type_t;
 
 /* for lvm_show_size () */
@@ -281,7 +285,6 @@ int    pv_move_pes ( vg_t*, char*, size_t, char**, int, int,
 int    pv_move_pe ( vg_t*, char*, size_t, long, long, long, long,
                     int, int, int, int);
 int    pv_read ( char *, pv_t **, int *);
-int    pv_read_already_red ( char *);
 int    pv_read_pe ( pv_t *, pe_disk_t **);
 int    pv_read_all_pv ( pv_t ***, int);
 int    pv_read_all_pv_of_vg ( char *, pv_t ***, int);
