@@ -39,9 +39,7 @@ int lv_write_all_pv ( vg_t *vg, int l) {
    int p = 0;
    int ret = 0;
 
-#ifdef DEBUG
    debug_enter ( "lv_write_all_pv -- CALLED with l: %d\n", l);
-#endif
 
    if ( vg == NULL) ret = -LVM_EPARAM;
    else {
@@ -51,8 +49,6 @@ int lv_write_all_pv ( vg_t *vg, int l) {
       }
    }
 
-#ifdef DEBUG
    debug_leave ( "lv_write_all_pv -- LEAVING with ret: %d\n", ret);
-#endif
    return ret;
 }
