@@ -37,34 +37,29 @@
 #include <liblvm.h>
 
 
+/* validates vg and each pv_name in vg_write */
 int vg_write_with_pv_and_lv ( vg_t *vg) {
    int p = 0;
    int ret = 0;
 
-#ifdef DEBUG
    debug_enter ( "vg_write_with_pv_and_lv -- CALLED\n");
-#endif
 
-   if ( vg == NULL ||
-        vg_check_name ( vg->vg_name) < 0) ret = -LVM_EPARAM;
+   if ( vg == NULL)
+        ret = -LVM_EPARAM;
    else {
       for ( p = 0; p < vg->pv_cur; p++) {
          if ( vg->pv[p] == NULL) continue;
-#ifdef DEBUG
          debug ( "vg_write_with_pv_and_lv -- BEFORE vg_write of %s\n",
                   vg->pv[p]->pv_name);
-#endif
          if ( ( ret = vg_write ( vg->pv[p]->pv_name, vg->pv[p], vg)) < 0) break;
+         if ( ( ret = pv_write_uuidlist ( vg->pv[p]->pv_name, vg)) < 0) break;
          if ( ( ret = pv_write_with_pe ( vg->pv[p]->pv_name,
                                          vg->pv[p])) < 0) break;
-         if ( ( ret = pv_write_uuidlist ( vg->pv[p]->pv_name, vg)) < 0) break;
          if ( ( ret = lv_write_all_lv ( vg->pv[p]->pv_name, vg)) < 0)
             break;
       }
    }
 
-#ifdef DEBUG
    debug_leave ( "vg_write_with_pv_and_lv -- LEAVING with ret: %d\n", ret);
-#endif
    return ret;
 }
