@@ -42,6 +42,7 @@
  *    20/05/1999 - fixed MAX_LV check
  *    06/10/1999 - implemented support for long options
  *    15/02/2000 - use lvm_error()
+ *    23/01/2001 - added call to lvm_init (JT)
  *
  */
 
@@ -53,6 +54,27 @@ char *cmd = NULL;
 int opt_d = 0;
 #endif
 
+void usage ( int ret)
+{
+   FILE *stream = stderr;
+
+   if ( ret == 0) {
+      stream = stdout;
+      printf ( "%s (IOP %d)\n\n", lvm_version, LVM_LIB_IOP_VERSION);
+      printf ( "%s -- re-register exported volume group with system\n", cmd);
+   }
+
+   fprintf ( stream, "\n%s "
+             DEBUG_HELP_2
+             "[-f|--force] "
+             "[-h|--help] "
+             "[-v|--verbose]\n\t"
+             "VolumeGroupName PhysicalVolumePath "
+             "[PhysicalVolumePath...]\n",
+             cmd);
+   exit ( ret);
+}
+
 int main ( int argc, char **argv) {
    int blk_dev = 0;
    int blk_dev_free_count = 0;
@@ -67,18 +89,13 @@ int main ( int argc, char **argv) {
    char *pv_name = NULL;
    char *vg_name = NULL;
    char vg_name_this[NAME_LEN] = { 0, };
-#ifdef DEBUG
-   char *options = "dfh?v";
-#else
-   char *options = "fh?v";
-#endif
+   char *options = "fh?v" DEBUG_SHORT_OPTION;
    struct option long_options[] = {
-#ifdef DEBUG
-      { "debug",   no_argument, NULL, 'd'},
-#endif
+      DEBUG_LONG_OPTION
       { "force",   no_argument, NULL, 'f'},
       { "help",    no_argument, NULL, 'h'},
       { "verbose", no_argument, NULL, 'v'},
+      { "version", no_argument, NULL, 22},
       { NULL,      0,           NULL, 0},
    };
    int opt_f = 0;
@@ -88,72 +105,48 @@ int main ( int argc, char **argv) {
    pv_t **pv_this = NULL;
    vg_t *vg = NULL;
 
+   /* lvm_init(argc, argv); */
    cmd = basename ( argv[0]);
 
-   SUSER_CHECK;
    LVMTAB_CHECK;
 
    while ( ( c = getopt_long ( argc, argv, options,
                                long_options, NULL)) != EOF) {
       switch ( c) {
-#ifdef DEBUG
-         case 'd':
-            if ( opt_d > 0) {
-               fprintf ( stderr, "%s -- d option already given\n\n", cmd);
-               return LVM_EINVALID_CMD_LINE;
-            }
-            opt_d++;
-            break;
-#endif
+         DEBUG_HANDLE_CASE_D;
 
          case 'f':
-            if ( opt_f > 0) {
-               fprintf ( stderr, "%s -- f option already given\n\n", cmd);
-               return LVM_EINVALID_CMD_LINE;
-            }
             opt_f++;
             break;
 
          case 'h':
-         case '?':
-            printf ( "\n%s  (IOP %d)\n\n%s -- Volume Group Import\n\n"
-                     "Synopsis:\n"
-                     "---------\n\n"
-                     "%s\n"
-#ifdef DEBUG
-                     "\t[-d/--debug]\n"
-#endif
-                     "\t[-f/--force]\n"
-                     "\t[-h/-?/--help]\n"
-                     "\t[-v/--verbose]\n"
-                     "\tVolumeGroupName PhysicalVolumePath "
-                     "[PhysicalVolumePath...]\n\n",
-                     lvm_version, LVM_LIB_IOP_VERSION,  cmd, cmd);
-            return 0;
-            break;
+            usage ( 0);
 
          case 'v':
-            if ( opt_v > 0) {
-               fprintf ( stderr, "%s -- v option already given\n\n", cmd);
-               return LVM_EINVALID_CMD_LINE;
-            }
             opt_v++;
             break;
 
          default:
             fprintf ( stderr, "%s -- invalid command line option \"%c\"\n\n",
                       cmd, c);
+         case '?':
             return LVM_EINVALID_CMD_LINE;
       }
    }
-  
+
+   /* not until all commands are converted
    CMD_MINUS_CHK;
+   */
+   if ( optind < argc && *argv[optind] == '-') {
+      fprintf ( stderr, "%s -- invalid option %s\n", cmd, argv[optind]);
+      usage ( LVM_EINVALID_CMD_LINE);
+   }
    LVM_CHECK_IOP;
    LVM_LOCK ( 0);
 
    if ( optind == argc) {
       fprintf ( stderr, "%s -- please give a volume group name\n\n", cmd);
-      return LVM_EVGIMPORT_VG_MISSING;
+      usage ( LVM_EVGIMPORT_VG_MISSING);
    }
 
    vg_name = argv[optind++];
@@ -161,12 +154,12 @@ int main ( int argc, char **argv) {
    if ( vg_check_name ( vg_name) < 0) {
       fprintf ( stderr, "%s -- invalid volume group name \"%s\"\n\n",
                         cmd, vg_name);
-      return LVM_EVGIMPORT_VG_CHECK_NAME;
+      usage ( LVM_EVGIMPORT_VG_CHECK_NAME);
    }
 
    if ( optind == argc) {
       fprintf ( stderr, "%s -- please enter a physical volume path\n\n", cmd);
-      return LVM_EVGIMPORT_PV_MISSING;
+      usage ( LVM_EVGIMPORT_PV_MISSING);
    }
 
    if ( opt_v > 0) printf ( "%s -- checking volume group \"%s\" existence\n",
@@ -174,7 +167,7 @@ int main ( int argc, char **argv) {
    if ( ( ret = lvm_tab_vg_check_exist ( vg_name, NULL)) == TRUE) {
       fprintf ( stderr, "%s -- a volume group named \"%s\" already exists\n\n",
                 cmd, vg_name);
-      return LVM_EVGIMPORT_VG_CHECK_EXIST;
+      usage ( LVM_EVGIMPORT_VG_CHECK_EXIST);
    }
 
    /* get the physical volume data */
@@ -184,12 +177,11 @@ int main ( int argc, char **argv) {
    for ( ; optind < argc; optind++) {
       pv_name = argv[optind];
 
-      if ( opt_v > 0) printf ( "%s -- checking for multiple "
-                               "physical volumes\n", cmd);
+      if ( opt_v > 0)
+         printf ( "%s -- checking for duplicate physical volumes\n", cmd);
       for ( p1 = 0; pv_this != NULL && pv_this[p1] != NULL; p1++) {
          if ( strcmp ( pv_name, pv_this[p1]->pv_name) == 0) {
-            fprintf ( stderr, "%s -- ERROR: physical volume \"%s\" occurs "
-                              "multiple times\n\n",
+            fprintf ( stderr, "%s -- duplicate physical volume \"%s\" \n\n",
                                cmd, pv_name);
             return LVM_EVGIMPORT_PV_MULTIPLE;
          }
@@ -203,25 +195,26 @@ int main ( int argc, char **argv) {
          return LVM_EVGIMPORT_PV_CHECK_NAME;
       }
 
-      if ( opt_v > 0) printf ( "%s -- reading data of physical volume \"%s\" "
-                               "from disk\n", cmd, pv_name);
+      if ( opt_v > 0)
+         printf ( "%s -- reading data of physical volume \"%s\" from disk\n",
+		   cmd, pv_name);
       if ( ( ret = pv_read ( pv_name, &pv, NULL)) < 0 &&
            ret != -LVM_EPV_READ_PV_EXPORTED) {
-         fprintf ( stderr, "%s -- ERROR \"%s\" reading data of physical "
-                           "volume \"%s\"\n\n",
+         fprintf ( stderr,
+		   "%s -- ERROR \"%s\" reading physical volume \"%s\"\n\n",
                            cmd, lvm_error ( ret), pv_name);
          return LVM_EVGIMPORT_PV_READ;
       }
 
-      if ( opt_v > 0) printf ( "%s -- checking for exported "
-                               "physical volume \"%s\"\n",
-                               cmd, pv_name);
+      if ( opt_v > 0)
+         printf ( "%s -- checking for exported physical volume \"%s\"\n",
+                  cmd, pv_name);
       if ( opt_f == 0 &&
            system_id_check_exported ( pv->system_id) == FALSE) {
          fprintf ( stderr, "%s -- ERROR: physical volume \"%s\" doesn't belong "
                            "to an exported volume group\n\n",
                            cmd, pv_name);
-         return LVM_EVGIMPORT_CHECK_EXPORTED;
+         usage ( LVM_EVGIMPORT_CHECK_EXPORTED);
       }
 
       if ( opt_v > 0) printf ( "%s -- reallocating memory\n", cmd);
@@ -229,7 +222,7 @@ int main ( int argc, char **argv) {
                                  ( p + 2) * sizeof ( pv_t*))) == NULL) {
          fprintf ( stderr, "%s -- realloc error in file \"%s\" [line %d]\n\n",
                            cmd, __FILE__, __LINE__);
-         return LVM_EVGIMPORT_REALLOC;
+         usage ( LVM_EVGIMPORT_REALLOC);
       }
 
       if ( ( pv_this[p] = malloc ( sizeof ( pv_t))) == NULL) {
@@ -265,10 +258,10 @@ int main ( int argc, char **argv) {
    for ( p = 1; pv_this[p] != NULL; p++) {
       if ( strcmp ( pv_this[0]->vg_name, pv_this[p]->vg_name) != 0 ||
            strcmp ( pv_this[0]->system_id, pv_this[p]->system_id) != 0) {
-         fprintf ( stderr, "%s -- physical volume \"%s\" doesn't belong to "
-                           "the same exported volume group as \"%s\"\n\n",
+         fprintf ( stderr, "%s -- physical volumes \"%s\" and \"%s\" are in "
+                           "different volume groups\n",
                    cmd, pv_this[p]->pv_name, pv_this[0]->pv_name);
-         return LVM_EVGIMPORT_VG_DIFF;
+         usage ( LVM_EVGIMPORT_VG_DIFF);
       }
       /* get the highest pv_number */
       if ( pv_number < pv_this[p]->pv_number) pv_number = pv_this[p]->pv_number;
@@ -362,9 +355,9 @@ int main ( int argc, char **argv) {
    /* correct the volume group name */
    strcpy ( vg->vg_name, vg_name);
 
-   if ( opt_v > 0) printf ( "%s -- importing physical volumes of volume "
-                            "group \"%s\"%s\n",
-                            cmd, vg->vg_name, opt_f > 1 ? "(forced)" : "");
+   if ( opt_v > 0)
+      printf ( "%s -- importing physical volumes of volume group \"%s\"%s\n",
+               cmd, vg->vg_name, opt_f > 1 ? "(forced)" : "");
    for ( p = 0; vg->pv[p] != NULL; p++) {
       system_id_set_imported ( vg->pv[p]->system_id);
       strcpy ( vg->pv[p]->vg_name, vg_name);
@@ -372,36 +365,36 @@ int main ( int argc, char **argv) {
 
    lvm_dont_interrupt ( 0);
 
-   if ( opt_v > 0) printf ( "%s -- getting free number for volume "
-                            "group \"%s\"\n\n",
-                            cmd, vg_name);
+   if ( opt_v > 0)
+      printf ( "%s -- getting free number for volume group \"%s\"\n\n",
+               cmd, vg_name);
    if ( ( vg->vg_number = lvm_tab_get_free_vg_number ()) < 0) {
-      fprintf ( stderr, "%s -- ERROR getting free number for volume "
-                        "group \"%s\"\n\n",
-                        cmd, vg_name);
+      fprintf ( stderr,
+                "%s -- ERROR getting free number for volume group \"%s\"\n\n",
+                cmd, vg_name);
       return LVM_EVGIMPORT_GET_FREE_VG_NUMBER;
    }
 
-   if ( opt_v > 0) printf ( "%s -- getting free block device numbers for "
-                            "volume group \"%s\"\n\n",
-                            cmd, vg_name);
+   if ( opt_v > 0)
+      printf ( "%s -- getting block device numbers for logical volumes\n\n",
+               cmd);
    if ( ( blk_dev_free_count = lvm_tab_get_free_blk_dev ( &blk_dev_free)) < 0) {
-      fprintf ( stderr, "%s -- ERROR \"%s\" getting free block device "
-                        "numbers\n\n",
+      fprintf ( stderr,
+                "%s -- ERROR \"%s\" getting free block device numbers\n\n",
                         cmd, lvm_error ( blk_dev_free_count));
       return LVM_EVGIMPORT_NO_DEV;
    }
 
    if ( blk_dev_free_count < vg->lv_cur) {
-      fprintf ( stderr, "%s -- only %d free LVM block devices available vs. "
-                        "%d needed\n\n",
-                        cmd, blk_dev_free_count, vg->lv_cur);
+      fprintf ( stderr,
+                "%s -- only %d block devices available but %d needed\n\n",
+                cmd, blk_dev_free_count, vg->lv_cur);
       return LVM_EVGIMPORT_NO_DEV;
    }
 
-   if ( opt_v > 0) printf ( "%s -- importing logical volumes of volume "
-                            "group \"%s\"\n",
-                            cmd, vg->vg_name);
+   if ( opt_v > 0)
+      printf ( "%s -- importing logical volumes of volume group \"%s\"\n",
+               cmd, vg->vg_name);
    for ( blk_dev = l = 0; l < vg->lv_max; l++) {
       if ( vg->lv[l] != NULL) {
          strcpy ( vg->lv[l]->vg_name, vg_name);
@@ -414,13 +407,12 @@ int main ( int argc, char **argv) {
    /* correct status to import */
    vg->vg_status &= ~VG_EXPORTED;
 
-   if ( opt_v > 0) printf ( "%s -- storing data of imported volume group "
-                            "\"%s\" " "on disk(s)\n",
-                            cmd, vg_name);
+   if ( opt_v > 0)
+      printf ( "%s -- storing data of imported volume group on disk(s)\n", cmd);
    if ( ( ret = vg_write_with_pv_and_lv ( vg)) < 0) {
-      fprintf ( stderr, "%s -- ERROR \"%s\" storing data of imported volume "
-                        "\"%s\" on disks\n\n",
-                        cmd, lvm_error ( ret), vg_name);
+      fprintf ( stderr,
+                "%s -- ERROR \"%s\" storing data of imported volume on disk\n",
+                cmd, lvm_error ( ret));
       return LVM_EVGIMPORT_VG_WRITE;
    }
 
@@ -439,9 +431,9 @@ int main ( int argc, char **argv) {
       return LVM_EVGIMPORT_VG_CREATE;
    }
 
-   if ( opt_v > 0) printf ( "%s -- inserting volume group "
-                            "\"%s\" into \"%s\"\n",
-                            cmd, vg_name, LVMTAB);
+   if ( opt_v > 0)
+      printf ( "%s -- inserting volume group \"%s\" into \"%s\"\n",
+               cmd, vg_name, LVMTAB);
    if ( ( ret = lvm_tab_vg_insert ( vg_name)) < 0) {
       fprintf ( stderr, "%s -- ERROR \"%s\" inserting volume group \"%s\" "
                        "into \"%s\"\n\n",
